Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaBatchUpdateResourcePoliciesRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaBatchUpdateResourcePoliciesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb
Overview
Request message for the BatchUpdateResourcePolicies method.
Instance Attribute Summary collapse
-
#requests ⇒ Array<Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaUpdateResourcePolicyRequest>
Required.
-
#update_mask ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaBatchUpdateResourcePoliciesRequest
constructor
A new instance of GoogleFirebaseAppcheckV1betaBatchUpdateResourcePoliciesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaBatchUpdateResourcePoliciesRequest
Returns a new instance of GoogleFirebaseAppcheckV1betaBatchUpdateResourcePoliciesRequest.
265 266 267 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#requests ⇒ Array<Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaUpdateResourcePolicyRequest>
Required. The request messages specifying the ResourcePolicy objects to update.
A maximum of 100 objects can be updated in a batch.
Corresponds to the JSON property requests
255 256 257 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 255 def requests @requests end |
#update_mask ⇒ String
Optional. A comma-separated list of names of fields in the ResourcePolicy
objects to update. Example: enforcement_mode. If this field is present, the
update_mask field in the UpdateResourcePolicyRequest messages must all match
this field, or the entire batch fails and no updates will be committed.
Corresponds to the JSON property updateMask
263 264 265 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 263 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
270 271 272 273 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 270 def update!(**args) @requests = args[:requests] if args.key?(:requests) @update_mask = args[:update_mask] if args.key?(:update_mask) end |