Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaBatchUpdateServicesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

Request message for the BatchUpdateServices method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaBatchUpdateServicesRequest

Returns a new instance of GoogleFirebaseAppcheckV1betaBatchUpdateServicesRequest.



313
314
315
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#requestsArray<Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaUpdateServiceRequest>

Required. The request messages specifying the Services to update. A maximum of 100 objects can be updated in a batch. Corresponds to the JSON property requests



303
304
305
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 303

def requests
  @requests
end

#update_maskString

Optional. A comma-separated list of names of fields in the Services to update. Example: display_name. If the update_mask field is set in both this request and any of the UpdateServiceRequest messages, they must match or the entire batch fails and no updates will be committed. Corresponds to the JSON property updateMask

Returns:

  • (String)


311
312
313
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 311

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



318
319
320
321
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 318

def update!(**args)
  @requests = args[:requests] if args.key?(:requests)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end