Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaDeviceCheckConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

An app's DeviceCheck configuration object. This configuration is used by ExchangeDeviceCheckToken to validate device tokens issued to apps by DeviceCheck. It also controls certain properties of the returned AppCheckToken, such as its ttl. Note that the Team ID registered with your app is used as part of the validation process. Please register it via the Firebase Console or programmatically via the Firebase Management Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaDeviceCheckConfig

Returns a new instance of GoogleFirebaseAppcheckV1betaDeviceCheckConfig.



443
444
445
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#key_idString

Required. The key identifier of a private key enabled with DeviceCheck, created in your Apple Developer account. Corresponds to the JSON property keyId

Returns:

  • (String)


412
413
414
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 412

def key_id
  @key_id
end

#nameString

Required. The relative resource name of the DeviceCheck configuration object, in the format: `projects/`project_number`/apps/`app_id`/deviceCheckConfig Corresponds to the JSON propertyname`

Returns:

  • (String)


419
420
421
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 419

def name
  @name
end

#private_keyString

Required. Input only. The contents of the private key (.p8) file associated with the key specified by key_id. For security reasons, this field will never be populated in any response. Corresponds to the JSON property privateKey

Returns:

  • (String)


426
427
428
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 426

def private_key
  @private_key
end

#private_key_setBoolean Also known as: private_key_set?

Output only. Whether the private_key field was previously set. Since we will never return the private_key field, this field is the only way to find out whether it was previously set. Corresponds to the JSON property privateKeySet

Returns:

  • (Boolean)


433
434
435
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 433

def private_key_set
  @private_key_set
end

#token_ttlString

Specifies the duration for which App Check tokens exchanged from DeviceCheck tokens will be valid. If unset, a default value of 1 hour is assumed. Must be between 30 minutes and 7 days, inclusive. Corresponds to the JSON property tokenTtl

Returns:

  • (String)


441
442
443
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 441

def token_ttl
  @token_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



448
449
450
451
452
453
454
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 448

def update!(**args)
  @key_id = args[:key_id] if args.key?(:key_id)
  @name = args[:name] if args.key?(:name)
  @private_key = args[:private_key] if args.key?(:private_key)
  @private_key_set = args[:private_key_set] if args.key?(:private_key_set)
  @token_ttl = args[:token_ttl] if args.key?(:token_ttl)
end