Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaExchangeAppAttestAssertionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

Request message for the ExchangeAppAttestAssertion method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaExchangeAppAttestAssertionRequest

Returns a new instance of GoogleFirebaseAppcheckV1betaExchangeAppAttestAssertionRequest.



491
492
493
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifactString

Required. The artifact returned by a previous call to ExchangeAppAttestAttestation. Corresponds to the JSON property artifact NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


466
467
468
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 466

def artifact
  @artifact
end

#assertionString

Required. The CBOR-encoded assertion returned by the client-side App Attest API. Corresponds to the JSON property assertion NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


473
474
475
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 473

def assertion
  @assertion
end

#challengeString

Required. A one-time challenge returned by an immediately prior call to GenerateAppAttestChallenge. Corresponds to the JSON property challenge NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


480
481
482
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 480

def challenge
  @challenge
end

#limited_useBoolean Also known as: limited_use?

Specifies whether this attestation is for use in a limited use (true) or * session based* (false) context. To enable this attestation to be used with the replay protection feature, set this to true. The default value is false. Corresponds to the JSON property limitedUse

Returns:

  • (Boolean)


488
489
490
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 488

def limited_use
  @limited_use
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



496
497
498
499
500
501
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 496

def update!(**args)
  @artifact = args[:artifact] if args.key?(:artifact)
  @assertion = args[:assertion] if args.key?(:assertion)
  @challenge = args[:challenge] if args.key?(:challenge)
  @limited_use = args[:limited_use] if args.key?(:limited_use)
end