Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaPlayIntegrityConfigDeviceIntegrity
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaPlayIntegrityConfigDeviceIntegrity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb
Overview
A settings object specifying device integrity requirements for Android devices running your app. These settings correspond to requirements on the device integrity field obtained from the Play Integrity API. See the default responses table for a quick summary. Warning: There are also conditional as well as optional responses that you can receive, but requires additional explicit opt-in from you. The App Check API is not responsible for any such opt-ins. The default values for these settings work for most apps, and are recommended.
Instance Attribute Summary collapse
-
#min_device_recognition_level ⇒ String
Specifies the minimum device integrity level in order for the device to be considered valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaPlayIntegrityConfigDeviceIntegrity
constructor
A new instance of GoogleFirebaseAppcheckV1betaPlayIntegrityConfigDeviceIntegrity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaPlayIntegrityConfigDeviceIntegrity
Returns a new instance of GoogleFirebaseAppcheckV1betaPlayIntegrityConfigDeviceIntegrity.
1143 1144 1145 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#min_device_recognition_level ⇒ String
Specifies the minimum device integrity level in order for the device to be
considered valid. Any device with a device recognition verdict lower than this
level will be rejected. If this is unspecified, the default level is
NO_INTEGRITY.
Corresponds to the JSON property minDeviceRecognitionLevel
1141 1142 1143 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1141 def min_device_recognition_level @min_device_recognition_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1148 1149 1150 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1148 def update!(**args) @min_device_recognition_level = args[:min_device_recognition_level] if args.key?(:min_device_recognition_level) end |