Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaRecaptchaConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

An app's reCAPTCHA v3 configuration object. This configuration is used by ExchangeRecaptchaToken to validate reCAPTCHA tokens issued to apps by reCAPTCHA v3. It also controls certain properties of the returned AppCheckToken, such as its ttl.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaRecaptchaConfig

Returns a new instance of GoogleFirebaseAppcheckV1betaRecaptchaConfig.



1272
1273
1274
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#min_valid_scoreFloat

Specifies a minimum score required for a reCAPTCHA token to be considered valid. If its score is greater than or equal to this value, it will be accepted; otherwise, it will be rejected. The value must be between 0.0 and 1.

  1. The default value is 0.5. Corresponds to the JSON property minValidScore

Returns:

  • (Float)


1242
1243
1244
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1242

def min_valid_score
  @min_valid_score
end

#nameString

Required. The relative resource name of the reCAPTCHA v3 configuration object, in the format: projects/`project_number`/apps/`app_id`/recaptchaConfig Corresponds to the JSON property name

Returns:

  • (String)


1248
1249
1250
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1248

def name
  @name
end

#site_secretString

Required. Input only. The site secret used to identify your service for reCAPTCHA v3 verification. For security reasons, this field will never be populated in any response. Corresponds to the JSON property siteSecret

Returns:

  • (String)


1255
1256
1257
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1255

def site_secret
  @site_secret
end

#site_secret_setBoolean Also known as: site_secret_set?

Output only. Whether the site_secret field was previously set. Since we will never return the site_secret field, this field is the only way to find out whether it was previously set. Corresponds to the JSON property siteSecretSet

Returns:

  • (Boolean)


1262
1263
1264
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1262

def site_secret_set
  @site_secret_set
end

#token_ttlString

Specifies the duration for which App Check tokens exchanged from reCAPTCHA tokens will be valid. If unset, a default value of 1 day is assumed. Must be between 30 minutes and 7 days, inclusive. Corresponds to the JSON property tokenTtl

Returns:

  • (String)


1270
1271
1272
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1270

def token_ttl
  @token_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1277
1278
1279
1280
1281
1282
1283
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1277

def update!(**args)
  @min_valid_score = args[:min_valid_score] if args.key?(:min_valid_score)
  @name = args[:name] if args.key?(:name)
  @site_secret = args[:site_secret] if args.key?(:site_secret)
  @site_secret_set = args[:site_secret_set] if args.key?(:site_secret_set)
  @token_ttl = args[:token_ttl] if args.key?(:token_ttl)
end