Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

An app's reCAPTCHA Enterprise configuration object. This configuration is used by ExchangeRecaptchaEnterpriseToken to validate reCAPTCHA tokens issued to apps by reCAPTCHA Enterprise. It also controls certain properties of the returned AppCheckToken, such as its ttl.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig

Returns a new instance of GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig.



1327
1328
1329
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The relative resource name of the reCAPTCHA Enterprise configuration object, in the format: projects/`project_number`/apps/`app_id`/ recaptchaEnterpriseConfig Corresponds to the JSON property name

Returns:

  • (String)


1298
1299
1300
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1298

def name
  @name
end

#risk_analysisGoogle::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigRiskAnalysis

A settings object specifying risk tolerance and requirements for your application. These settings correspond to requirements on the *riskAnalysis * tuple in the assessment obtained from reCAPTCHA Enterprise. The default values for these settings work for most apps, and are recommended. Corresponds to the JSON property riskAnalysis



1308
1309
1310
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1308

def risk_analysis
  @risk_analysis
end

#site_keyString

The score-based site key created in reCAPTCHA Enterprise used to invoke reCAPTCHA and generate the reCAPTCHA tokens for your application. Important: This is not the site_secret (as it is in reCAPTCHA v3), but rather your score-based reCAPTCHA Enterprise site key. Corresponds to the JSON property siteKey

Returns:

  • (String)


1318
1319
1320
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1318

def site_key
  @site_key
end

#token_ttlString

Specifies the duration for which App Check tokens exchanged from reCAPTCHA Enterprise tokens will be valid. If unset, a default value of 1 hour is assumed. Must be between 30 minutes and 7 days, inclusive. Corresponds to the JSON property tokenTtl

Returns:

  • (String)


1325
1326
1327
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1325

def token_ttl
  @token_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1332
1333
1334
1335
1336
1337
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1332

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @risk_analysis = args[:risk_analysis] if args.key?(:risk_analysis)
  @site_key = args[:site_key] if args.key?(:site_key)
  @token_ttl = args[:token_ttl] if args.key?(:token_ttl)
end