Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaResourcePolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

App Check enforcement policy for a specific resource of a Google service supported by App Check. Note that this policy will override the service-level configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaResourcePolicy

Returns a new instance of GoogleFirebaseAppcheckV1betaResourcePolicy.



1473
1474
1475
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enforcement_modeString

Required. The baseline protection EnforcementMode for this resource. This will override the service-level baseline protection EnforcementMode. Corresponds to the JSON property enforcementMode

Returns:

  • (String)


1435
1436
1437
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1435

def enforcement_mode
  @enforcement_mode
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. This etag is strongly validated as defined by RFC 7232. Corresponds to the JSON property etag

Returns:

  • (String)


1443
1444
1445
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1443

def etag
  @etag
end

#nameString

Required. Identifier. The relative name of the resource policy object, in the format: projects/`project_number`/services/`service_id`/resourcePolicies/` resource_policy_id` Note that the service_id element must be a supported service ID. Currently, the following service IDs are supported: * oauth2. googleapis.com (Google Identity for iOS) resource_policy_id is a system- generated UID. Corresponds to the JSON property name

Returns:

  • (String)


1453
1454
1455
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1453

def name
  @name
end

#target_resourceString

Required. Service specific name of the resource object to which this policy applies, in the format: * iOS OAuth clients (Google Identity for iOS): // oauth2.googleapis.com/projects/project_number/oauthClients/oauth_client_id` Note that the resource must belong to the service specified in thenameand be from the same project as this policy, but the resource is allowed to be missing at the time of creation of this policy; in that case, we make a best- effort attempt at respecting this policy, but it may not have any effect until the resource is fully created. Corresponds to the JSON propertytargetResource`

Returns:

  • (String)


1465
1466
1467
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1465

def target_resource
  @target_resource
end

#update_timeString

Output only. Timestamp when this resource policy configuration object was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1471
1472
1473
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1471

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1478
1479
1480
1481
1482
1483
1484
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1478

def update!(**args)
  @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @target_resource = args[:target_resource] if args.key?(:target_resource)
  @update_time = args[:update_time] if args.key?(:update_time)
end