Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaUpdateResourcePolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

Request message for the UpdateResourcePolicy method as well as an individual update message for the BatchUpdateResourcePolicies method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaUpdateResourcePolicyRequest

Returns a new instance of GoogleFirebaseAppcheckV1betaUpdateResourcePolicyRequest.



1577
1578
1579
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_policyGoogle::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaResourcePolicy

App Check enforcement policy for a specific resource of a Google service supported by App Check. Note that this policy will override the service-level configuration. Corresponds to the JSON property resourcePolicy



1569
1570
1571
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1569

def resource_policy
  @resource_policy
end

#update_maskString

Required. A comma-separated list of names of fields in the ResourcePolicy to update. Example: enforcement_mode. Corresponds to the JSON property updateMask

Returns:

  • (String)


1575
1576
1577
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1575

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1582
1583
1584
1585
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1582

def update!(**args)
  @resource_policy = args[:resource_policy] if args.key?(:resource_policy)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end