Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaUpdateServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

Request message for the UpdateService method as well as an individual update message for the BatchUpdateServices method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaUpdateServiceRequest

Returns a new instance of GoogleFirebaseAppcheckV1betaUpdateServiceRequest.



1668
1669
1670
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceGoogle::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaService

The enforcement configuration for a Firebase service supported by App Check. Corresponds to the JSON property service



1660
1661
1662
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1660

def service
  @service
end

#update_maskString

Required. A comma-separated list of names of fields in the Service to update. Example: enforcement_mode. Corresponds to the JSON property updateMask

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1666

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1673
1674
1675
1676
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1673

def update!(**args)
  @service = args[:service] if args.key?(:service)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end