Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaDebugToken
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaDebugToken
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb
Overview
A debug token is a secret used during the development or integration testing of an app. It essentially allows the development or integration testing to bypass app attestation while still allowing App Check to enforce protection on supported production Firebase services.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#token ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaDebugToken
constructor
A new instance of GoogleFirebaseAppcheckV1betaDebugToken.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaDebugToken
Returns a new instance of GoogleFirebaseAppcheckV1betaDebugToken.
383 384 385 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. A human readable display name used to identify this debug token.
Corresponds to the JSON property displayName
353 354 355 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 353 def display_name @display_name end |
#etag ⇒ String
Optional. This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client has
an up-to-date value before proceeding. This etag is strongly validated as
defined by RFC 7232.
Corresponds to the JSON property etag
361 362 363 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 361 def etag @etag end |
#name ⇒ String
Required. The relative resource name of the debug token, in the format:
projects/`project_number`/apps/`app_id`/debugTokens/`debug_token_id`
Corresponds to the JSON property name
367 368 369 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 367 def name @name end |
#token ⇒ String
Required. Input only. Immutable. The secret token itself. Must be provided
during creation, and must be a UUID4, case insensitive. This field is
immutable once set, and cannot be provided during a UpdateDebugToken request.
You can, however, delete this debug token using DeleteDebugToken to revoke it.
For security reasons, this field will never be populated in any response.
Corresponds to the JSON property token
376 377 378 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 376 def token @token end |
#update_time ⇒ String
Output only. Timestamp when this debug token was most recently updated.
Corresponds to the JSON property updateTime
381 382 383 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 381 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
388 389 390 391 392 393 394 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 388 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @token = args[:token] if args.key?(:token) @update_time = args[:update_time] if args.key?(:update_time) end |