Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaDebugToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

A debug token is a secret used during the development or integration testing of an app. It essentially allows the development or integration testing to bypass app attestation while still allowing App Check to enforce protection on supported production Firebase services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaDebugToken

Returns a new instance of GoogleFirebaseAppcheckV1betaDebugToken.



402
403
404
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. A human readable display name used to identify this debug token. Corresponds to the JSON property displayName

Returns:

  • (String)


372
373
374
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 372

def display_name
  @display_name
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. This etag is strongly validated as defined by RFC 7232. Corresponds to the JSON property etag

Returns:

  • (String)


380
381
382
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 380

def etag
  @etag
end

#nameString

Required. The relative resource name of the debug token, in the format: projects/`project_number`/apps/`app_id`/debugTokens/`debug_token_id` Corresponds to the JSON property name

Returns:

  • (String)


386
387
388
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 386

def name
  @name
end

#tokenString

Required. Input only. Immutable. The secret token itself. Must be provided during creation, and must be a UUID4, case insensitive. This field is immutable once set, and cannot be provided during an UpdateDebugToken request. You can, however, delete this debug token using DeleteDebugToken to revoke it. For security reasons, this field will never be populated in any response. Corresponds to the JSON property token

Returns:

  • (String)


395
396
397
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 395

def token
  @token
end

#update_timeString

Output only. Timestamp when this debug token was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


400
401
402
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 400

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



407
408
409
410
411
412
413
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 407

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @token = args[:token] if args.key?(:token)
  @update_time = args[:update_time] if args.key?(:update_time)
end