Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaExchangeCustomTokenRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

Request message for the ExchangeCustomToken method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaExchangeCustomTokenRequest

Returns a new instance of GoogleFirebaseAppcheckV1betaExchangeCustomTokenRequest.



640
641
642
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_tokenString

Required. A custom token signed using your project's Admin SDK service account credentials. Corresponds to the JSON property customToken

Returns:

  • (String)


611
612
613
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 611

def custom_token
  @custom_token
end

#jtiString

Optional. When limited_use is set to true, this field specifies the desired jti claim (Section 4.1.7 of RFC 7519) in the returned App Check token. Limited use App Check tokens with the same jti will be counted as the same token for the purposes of replay protection. An error is returned if this field is specified without setting limited_use to true. The size of this field is limited to 500 bytes. If specified, its length must be at least 16 bytes. If this field is omitted or is empty and limited_use is set to true, a randomly generated jti claim with length between 16 and 500 bytes ( inclusive) will be used in the returned App Check token. Leaving this field empty is only recommended if your custom attestation provider itself is not vulnerable to replay attacks. When limited_use is set to false, neither the presence nor the contents of the jti claim in the returned App Check token is specified. To ensure that the returned App Check token is eligible for limited use functionality, set limited_use to true. Corresponds to the JSON property jti

Returns:

  • (String)


629
630
631
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 629

def jti
  @jti
end

#limited_useBoolean Also known as: limited_use?

Specifies whether this attestation is for use in a limited use (true) or * session based* (false) context. To enable this attestation to be used with the replay protection feature, set this to true. The default value is false. Corresponds to the JSON property limitedUse

Returns:

  • (Boolean)


637
638
639
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 637

def limited_use
  @limited_use
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



645
646
647
648
649
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 645

def update!(**args)
  @custom_token = args[:custom_token] if args.key?(:custom_token)
  @jti = args[:jti] if args.key?(:jti)
  @limited_use = args[:limited_use] if args.key?(:limited_use)
end