Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb
Overview
A settings object specifying account requirements for Android devices running your app. These settings correspond to requirements on the account details field obtained from the Play Integrity API. See the default responses table for a quick summary. The default values for these settings work for most apps, and are recommended.
Instance Attribute Summary collapse
-
#require_licensed ⇒ Boolean
(also: #require_licensed?)
Specifies whether the caller must have received the
LICENSEDverdict.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails
constructor
A new instance of GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails
Returns a new instance of GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails.
1074 1075 1076 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#require_licensed ⇒ Boolean Also known as: require_licensed?
Specifies whether the caller must have received the LICENSED verdict.
For additional details about scenarios where your users will receive this
LICENSED label, see the default responses table. If set to true, apps without the
LICENSED app licensing verdict will be rejected. If set to false, any app
licensing verdict is allowed. The default value is false.
Corresponds to the JSON property requireLicensed
1071 1072 1073 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1071 def require_licensed @require_licensed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1079 1080 1081 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1079 def update!(**args) @require_licensed = args[:require_licensed] if args.key?(:require_licensed) end |