Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

A settings object specifying account requirements for Android devices running your app. These settings correspond to requirements on the account details field obtained from the Play Integrity API. See the default responses table for a quick summary. The default values for these settings work for most apps, and are recommended.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails

Returns a new instance of GoogleFirebaseAppcheckV1betaPlayIntegrityConfigAccountDetails.



1113
1114
1115
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#require_licensedBoolean Also known as: require_licensed?

Specifies whether the caller must have received the LICENSED verdict. For additional details about scenarios where your users will receive this LICENSED label, see the default responses table. If set to true, apps without the LICENSED app licensing verdict will be rejected. If set to false, any app licensing verdict is allowed. The default value is false. Corresponds to the JSON property requireLicensed

Returns:

  • (Boolean)


1110
1111
1112
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1110

def require_licensed
  @require_licensed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1118
1119
1120
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1118

def update!(**args)
  @require_licensed = args[:require_licensed] if args.key?(:require_licensed)
end