Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb

Overview

An app's reCAPTCHA Enterprise configuration object. This configuration is used by ExchangeRecaptchaEnterpriseToken to validate reCAPTCHA tokens issued to apps by reCAPTCHA Enterprise. It also controls certain properties of the returned AppCheckToken, such as its ttl.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig

Returns a new instance of GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfig.



1366
1367
1368
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The relative resource name of the reCAPTCHA Enterprise configuration object, in the format: projects/`project_number`/apps/`app_id`/ recaptchaEnterpriseConfig Corresponds to the JSON property name

Returns:

  • (String)


1337
1338
1339
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1337

def name
  @name
end

#risk_analysisGoogle::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigRiskAnalysis

A settings object specifying risk tolerance and requirements for your application. These settings correspond to requirements on the *riskAnalysis * tuple in the assessment obtained from reCAPTCHA Enterprise. The default values for these settings work for most apps, and are recommended. Corresponds to the JSON property riskAnalysis



1347
1348
1349
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1347

def risk_analysis
  @risk_analysis
end

#site_keyString

The score-based site key created in reCAPTCHA Enterprise used to invoke reCAPTCHA and generate the reCAPTCHA tokens for your application. Important: This is not the site_secret (as it is in reCAPTCHA v3), but rather your score-based reCAPTCHA Enterprise site key. Corresponds to the JSON property siteKey

Returns:

  • (String)


1357
1358
1359
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1357

def site_key
  @site_key
end

#token_ttlString

Specifies the duration for which App Check tokens exchanged from reCAPTCHA Enterprise tokens will be valid. If unset, a default value of 1 hour is assumed. Must be between 30 minutes and 7 days, inclusive. Corresponds to the JSON property tokenTtl

Returns:

  • (String)


1364
1365
1366
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1364

def token_ttl
  @token_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1371
1372
1373
1374
1375
1376
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1371

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @risk_analysis = args[:risk_analysis] if args.key?(:risk_analysis)
  @site_key = args[:site_key] if args.key?(:site_key)
  @token_ttl = args[:token_ttl] if args.key?(:token_ttl)
end