Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigRiskAnalysis
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigRiskAnalysis
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb
Overview
A settings object specifying risk tolerance and requirements for your
application. These settings correspond to requirements on the *riskAnalysis
* tuple in the assessment obtained from reCAPTCHA
Enterprise. The default values for these settings work for most apps, and are
recommended.
Instance Attribute Summary collapse
-
#min_valid_score ⇒ Float
Specifies a minimum score required for a reCAPTCHA token to be considered valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigRiskAnalysis
constructor
A new instance of GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigRiskAnalysis.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigRiskAnalysis
Returns a new instance of GoogleFirebaseAppcheckV1betaRecaptchaEnterpriseConfigRiskAnalysis.
1396 1397 1398 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1396 def initialize(**args) update!(**args) end |
Instance Attribute Details
#min_valid_score ⇒ Float
Specifies a minimum score required for a reCAPTCHA token to be considered valid. If its score is greater than or equal to this value, it will be accepted; otherwise, it will be rejected. The value must be between 0.0 and 1.
- The default value is 0.5.
Corresponds to the JSON property
minValidScore
1394 1395 1396 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1394 def min_valid_score @min_valid_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1401 1402 1403 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1401 def update!(**args) @min_valid_score = args[:min_valid_score] if args.key?(:min_valid_score) end |