Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaResourcePolicy
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaResourcePolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb
Overview
App Check enforcement policy for a specific resource of a Google service supported by App Check. Note that this policy will override the service-level configuration.
Instance Attribute Summary collapse
-
#enforcement_mode ⇒ String
Required.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#name ⇒ String
Required.
-
#target_resource ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaResourcePolicy
constructor
A new instance of GoogleFirebaseAppcheckV1betaResourcePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaResourcePolicy
Returns a new instance of GoogleFirebaseAppcheckV1betaResourcePolicy.
1512 1513 1514 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enforcement_mode ⇒ String
Required. The App Check enforcement mode for this resource. This will override
the EnforcementMode setting on the parent service.
Corresponds to the JSON property enforcementMode
1474 1475 1476 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1474 def enforcement_mode @enforcement_mode end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding. This etag is strongly validated as defined by
RFC 7232.
Corresponds to the JSON property etag
1482 1483 1484 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1482 def etag @etag end |
#name ⇒ String
Required. Identifier. The relative name of the resource policy object, in the
format: projects/`project_number`/services/`service_id`/resourcePolicies/`
resource_policy_id` Note that the service_id element must be a supported
service ID. Currently, the following service IDs are supported: * oauth2.
googleapis.com (Google Identity for iOS) resource_policy_id is a system-
generated UID.
Corresponds to the JSON property name
1492 1493 1494 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1492 def name @name end |
#target_resource ⇒ String
Required. Service specific name of the resource object to which this policy
applies, in the format: * iOS OAuth clients (Google Identity for iOS): //
oauth2.googleapis.com/projects/project_number/oauthClients/oauth_client_id`
Note that the resource must belong to the service specified in thenameand
be from the same project as this policy, but the resource is allowed to be
missing at the time of creation of this policy; in that case, we make a best-
effort attempt at respecting this policy, but it may not have any effect until
the resource is fully created.
Corresponds to the JSON propertytargetResource`
1504 1505 1506 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1504 def target_resource @target_resource end |
#update_time ⇒ String
Output only. Timestamp when this resource policy configuration object was most
recently updated.
Corresponds to the JSON property updateTime
1510 1511 1512 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1510 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1517 def update!(**args) @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @target_resource = args[:target_resource] if args.key?(:target_resource) @update_time = args[:update_time] if args.key?(:update_time) end |