Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaService
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb
Overview
The enforcement configuration for a Firebase service supported by App Check.
Instance Attribute Summary collapse
-
#enforcement_mode ⇒ String
Required.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#name ⇒ String
Required.
-
#replay_protection ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaService
constructor
A new instance of GoogleFirebaseAppcheckV1betaService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaService
Returns a new instance of GoogleFirebaseAppcheckV1betaService.
1540 1541 1542 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enforcement_mode ⇒ String
Required. The baseline protection EnforcementMode for this service.
Corresponds to the JSON property enforcementMode
1494 1495 1496 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1494 def enforcement_mode @enforcement_mode end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding. This etag is strongly validated as defined by
RFC 7232.
Corresponds to the JSON property etag
1502 1503 1504 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1502 def etag @etag end |
#name ⇒ String
Required. The relative resource name of the service configuration object, in
the format: projects/`project_number`/services/`service_id` Note that
the service_id element must be a supported service ID. Currently, the
following service IDs are supported. Firebase and Google Cloud services: *
identitytoolkit.googleapis.com (Firebase Authentication) *
firebasedataconnect.googleapis.com (Firebase SQL Connect) * firestore.
googleapis.com (Cloud Firestore) * firebasedatabase.googleapis.com (
Firebase Realtime Database) * firebasestorage.googleapis.com (Cloud Storage
for Firebase) * firebaseml.googleapis.com (Firebase AI Logic) Google Maps
Platform services: * maps-backend.googleapis.com (Maps JavaScript API) *
places.googleapis.com (Places API (New)) Other supported Google services: *
oauth2.googleapis.com (Google Identity for iOS)
Corresponds to the JSON property name
1518 1519 1520 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1518 def name @name end |
#replay_protection ⇒ String
Optional. The replay protection EnforcementMode for this service. Note that
this field cannot be set to a level higher than that of baseline protection.
For example, if the enforcement mode for baseline protection is set to
UNENFORCED, this field cannot be set to ENFORCED. In order to enforce
replay protection, you must first enforce App Check's baseline protection. An
HTTP 400 error will be returned in this case. By default, this field is set to
OFF. Setting this field to UNENFORCED or ENFORCED is considered opting
into replay protection. Opting in can impact your requests by adding some
latency and sometimes cost (depending on your attestation provider). To opt
out of replay protection after opting in, set this field to OFF.
Corresponds to the JSON property replayProtection
1532 1533 1534 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1532 def replay_protection @replay_protection end |
#update_time ⇒ String
Output only. Timestamp when this service configuration object was most
recently updated.
Corresponds to the JSON property updateTime
1538 1539 1540 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1538 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1545 1546 1547 1548 1549 1550 1551 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1545 def update!(**args) @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @replay_protection = args[:replay_protection] if args.key?(:replay_protection) @update_time = args[:update_time] if args.key?(:update_time) end |