Class: Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaService
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1beta::GoogleFirebaseAppcheckV1betaService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1beta/classes.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb,
lib/google/apis/firebaseappcheck_v1beta/representations.rb
Overview
The enforcement configuration for a Firebase service supported by App Check.
Instance Attribute Summary collapse
-
#enforcement_mode ⇒ String
Required.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#name ⇒ String
Required.
-
#replay_protection ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaService
constructor
A new instance of GoogleFirebaseAppcheckV1betaService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1betaService
Returns a new instance of GoogleFirebaseAppcheckV1betaService.
1609 1610 1611 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1609 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enforcement_mode ⇒ String
Required. The App Check enforcement mode for this service.
Corresponds to the JSON property enforcementMode
1567 1568 1569 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1567 def enforcement_mode @enforcement_mode end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding. This etag is strongly validated as defined by
RFC 7232.
Corresponds to the JSON property etag
1575 1576 1577 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1575 def etag @etag end |
#name ⇒ String
Required. The relative resource name of the service configuration object, in
the format: projects/`project_number`/services/`service_id` Note that
the service_id element must be a supported service ID. Currently, the
following service IDs are supported: * firebasestorage.googleapis.com (Cloud
Storage for Firebase) * firebasedatabase.googleapis.com (Firebase Realtime
Database) * firestore.googleapis.com (Cloud Firestore) * identitytoolkit.
googleapis.com (Firebase Authentication with Identity Platform) * oauth2.
googleapis.com (Google Identity for iOS)
Corresponds to the JSON property name
1587 1588 1589 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1587 def name @name end |
#replay_protection ⇒ String
Optional. The replay protection enforcement mode for this service. Note that
this field cannot be set to a level higher than the overall App Check
enforcement mode. For example, if the overall App Check enforcement mode is
set to UNENFORCED, this field cannot be set to ENFORCED. In order to
enforce replay protection, you must first enforce App Check. An HTTP 400 error
will be returned in this case. By default, this field is set to OFF. Setting
this field to UNENFORCED or ENFORCED is considered opting into replay
protection. Once opted in, requests to your protected services may experience
higher latency. To opt out of replay protection after opting in, set this
field to OFF.
Corresponds to the JSON property replayProtection
1601 1602 1603 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1601 def replay_protection @replay_protection end |
#update_time ⇒ String
Output only. Timestamp when this service configuration object was most
recently updated.
Corresponds to the JSON property updateTime
1607 1608 1609 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1607 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1614 1615 1616 1617 1618 1619 1620 |
# File 'lib/google/apis/firebaseappcheck_v1beta/classes.rb', line 1614 def update!(**args) @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @replay_protection = args[:replay_protection] if args.key?(:replay_protection) @update_time = args[:update_time] if args.key?(:update_time) end |